(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      6391,        153]
NotebookOptionsPosition[      6120,        139]
NotebookOutlinePosition[      6453,        154]
CellTagsIndexPosition[      6410,        151]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<NETLink`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"LoadNETAssembly", "[", 
  RowBox[{"\"\<Tinkerforge\>\"", ",", 
   RowBox[{
    RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<../../..\>\""}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.600175052949191*^9, 3.600175066601799*^9}, 
   3.600175102142559*^9, {3.6001753172765293`*^9, 3.600175317946432*^9}, {
   3.600500538026902*^9, 3.600500561851948*^9}, {3.600506097634747*^9, 
   3.600506099012146*^9}, 3.600506136278721*^9, {3.60060805238198*^9, 
   3.600608117803465*^9}, {3.600608826318905*^9, 3.600608826675346*^9}, {
   3.600685674272073*^9, 3.600685674575115*^9}}],

Cell[BoxData[{
 RowBox[{"host", "=", "\"\<localhost\>\""}], "\n", 
 RowBox[{"port", "=", "4223"}], "\n", 
 RowBox[{
  RowBox[{"uid", "=", "\"\<XYZ\>\""}], 
  RowBox[{"(*", 
   RowBox[{"Change", " ", "to", " ", "your", " ", "UID"}], "*)"}], "\n", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Create", " ", "IPConnection", " ", "and", " ", "device", " ", "object"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"ipcon", "=", 
  RowBox[{"NETNew", "[", "\"\<Tinkerforge.IPConnection\>\"", "]"}]}], "\n", 
 RowBox[{"ai", "=", 
  RowBox[{"NETNew", "[", 
   RowBox[{"\"\<Tinkerforge.BrickletAnalogIn\>\"", ",", "uid", ",", "ipcon"}],
    "]"}]}], "\n", 
 RowBox[{
  RowBox[{"ipcon", "@", 
   RowBox[{"Connect", "[", 
    RowBox[{"host", ",", "port"}], "]"}]}], "\n", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Get", " ", "threshold", " ", "callbacks", " ", "with", " ", "a", " ", 
    "debounce", " ", "time", " ", "of", " ", "10", " ", "seconds", " ", 
    RowBox[{"(", 
     RowBox[{"10000", "ms"}], ")"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ai", "@", 
   RowBox[{"SetDebouncePeriod", "[", "10000", "]"}]}], "\n", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Callback", " ", "function", " ", "for", " ", "voltage", " ", "reached", 
    " ", "callback", " ", 
    RowBox[{"(", 
     RowBox[{"parameter", " ", "has", " ", "unit", " ", "mV"}], ")"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VoltageReachedCB", "[", 
   RowBox[{"sender_", ",", "voltage_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Voltage: \>\"", "<>", 
    RowBox[{"ToString", "[", 
     RowBox[{"N", "[", 
      RowBox[{"Quantity", "[", 
       RowBox[{"voltage", ",", "\"\<V/1000\>\""}], "]"}], "]"}], "]"}]}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{"AddEventHandler", "[", 
   RowBox[{
    RowBox[{"ai", "@", "VoltageReached"}], ",", "VoltageReachedCB"}], "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Configure", " ", "threshold", " ", "for", " ", "voltage", " ", 
    "\"\<smaller than 5 V\>\"", " ", 
    RowBox[{"(", 
     RowBox[{"unit", " ", "is", " ", "mV"}], ")"}]}], "*)"}]}], "\n", 
 RowBox[{"option", "=", 
  "Tinkerforge`BrickletAnalogIn`THRESHOLDUOPTIONUSMALLER"}], "\n", 
 RowBox[{
  RowBox[{"ai", "@", 
   RowBox[{"SetVoltageCallbackThreshold", "[", 
    RowBox[{"option", ",", 
     RowBox[{"5", "*", "1000"}], ",", "0"}], "]"}]}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Input", "[", "\"\<Click OK to exit\>\"", "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Clean", " ", "up"}], "*)"}]}], "\n", 
 RowBox[{"ipcon", "@", 
  RowBox[{"Disconnect", "[", "]"}]}], "\n", 
 RowBox[{"ReleaseNETObject", "[", "ai", "]"}], "\n", 
 RowBox[{"ReleaseNETObject", "[", "ipcon", "]"}]}], "Input",
 CellChangeTimes->{{3.600075175574196*^9, 3.600075177574486*^9}, {
   3.600075518821967*^9, 3.60007554243471*^9}, {3.600075580562348*^9, 
   3.600075669308506*^9}, {3.600075705822371*^9, 3.600075921974015*^9}, {
   3.6000760067507343`*^9, 3.600076009622583*^9}, {3.600077792659996*^9, 
   3.600077795613958*^9}, {3.600077854705127*^9, 3.600077855342334*^9}, {
   3.600090981053762*^9, 3.6000909897413397`*^9}, {3.600091048393783*^9, 
   3.600091071325759*^9}, {3.6000911068928633`*^9, 3.6000911072763557`*^9}, {
   3.600091413237206*^9, 3.600091428847453*^9}, {3.600091480127982*^9, 
   3.60009150669311*^9}, {3.6000915673213387`*^9, 3.6000915678002653`*^9}, {
   3.600092307925643*^9, 3.600092314241997*^9}, {3.600149020784099*^9, 
   3.6001491107582273`*^9}, {3.600149174456699*^9, 3.6001491869018793`*^9}, {
   3.600161252329417*^9, 3.600161270517737*^9}, {3.6001751050299597`*^9, 
   3.6001752269913054`*^9}, {3.600175283111157*^9, 3.60017529631222*^9}, {
   3.600500425825809*^9, 3.6005004326356916`*^9}, {3.6005005658827868`*^9, 
   3.60050056667803*^9}, {3.600506021813815*^9, 3.6005060779666643`*^9}, {
   3.600506152278829*^9, 3.6005061727773933`*^9}, {3.600607963780426*^9, 
   3.6006080340220013`*^9}, {3.600608128817329*^9, 3.600608130481505*^9}, {
   3.60060817038931*^9, 3.600608171010838*^9}, 3.60060822412246*^9, {
   3.600608254252864*^9, 3.600608318404385*^9}, {3.600608504672563*^9, 
   3.6006085096134768`*^9}, {3.600608564485358*^9, 3.6006085694976482`*^9}, {
   3.6006086083315887`*^9, 3.600608696478737*^9}, {3.600608732817322*^9, 
   3.600608760452553*^9}, {3.600608824736239*^9, 3.600608825481593*^9}, 
   3.60060918655473*^9, {3.600609227515625*^9, 3.600609227953993*^9}, {
   3.600609340818445*^9, 3.600609544802136*^9}, {3.600609618298398*^9, 
   3.6006096224709063`*^9}, 3.600610394591187*^9, {3.6006813189185*^9, 
   3.600681472190928*^9}, {3.600681510568192*^9, 3.6006815109077997`*^9}, 
   3.6006831479175043`*^9, {3.651555121506626*^9, 3.651555122736486*^9}}]
},
WindowSize->{1521, 867},
WindowMargins->{{241, 156}, {84, Automatic}},
FrontEndVersion->"9.0 for Linux x86 (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 676, 12, 55, "Input"],
Cell[1236, 34, 4880, 103, 605, "Input"]
}
]
*)

(* End of internal cache information *)
